..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

Installation
############

Install from PyPI
=================

.. code-block:: shell

    pip install nirahmq

Install from GitHub
===================

.. code-block:: shell

    pip install git+https://github.com/dionisis2014/nirahmq

Install from local clone
========================

.. code-block:: shell

    git clone https://github.com/dionisis2014/nirahmq
    cd nirahmq
    pip install .
